This is the open source version of the [HotWaterManager](https://www.thefloatinglab.world/en/boilers.html).

This HotWaterManager is intended for controlling the HotWater system on sailboats, features are:

- It can be build with an Arduino but also a customized circuit board ([ThermalOptimizer](https://git.thefloatinglab.world/TheFloatingLab/ThermalOptimizer)) is available.
- Uses the excess energy of the solar panels, once the batteries are fully charged, to heat the Hot Water Tank.
- It will instantly switch off the heating element when a heavy consumer switches on (anchor winch etc).
- Energy saving of 66% by heating up to 40&deg;C instead of 60&deg;C, but when there is an ambundant of energy allowing the water to heat up to 90&deg;C.
- Fast warmup mode to just "shower temperature" so you can take a shower for just 1/3th of the energy.
- Legionella prevention and warning, by periodically heating the water to a bacteria killing temperature or warning when it has been too long ago that this temperature could be reached.
- Can control a solenoid to switch off the hot water pressure after a configurable timer expires, to limit shower time and to reduce the chance of water leaks.
- Thermostatic control when connected to shore power.
- Can optionally control a pump based on a differential temperature, so you can build your own "solar panel" consisting of nothing more than just a hose on deck and a small electric pump.
- Guards the hot water tank against freezing.
- Automatic energy saving when it detects that the engine is running and coolant can be used to heat up the water.
- LCD display with hot water temperature, trend, voltage and heater status.
- Fully configurable by an on screen menu.
- Low energy use when not activated.
- Switchable between degrees Celsius and Fahrenheit, 12V and 24V systems.

See for details and background [https://www.thefloatinglab.world/en/boilers.html](https://www.thefloatinglab.world/en/boilers.html)

## Notes about the schematics

### Explanation of the Arduino version

- R1 and R2 are used to bring the reference voltage into the window of the ADC. R1 together with C1 also services as a *low pass filter* to filter out induction peaks.
- R10, R11 and R12 are used to control the brightness of the LCD. With these 3 resistors there are 8 brightness levels possible. Brightness control could also be achieved with a single PWM output, but PWM is not available during microcontroller sleep.
- Q1 controls the output relay which is used to switch the heater. The relay is not drawn on the schematic. One pin of the coil is connected to 12V (or 24V) and the other one to the transistor output.
- Q2 controls the optional Hot Water Solenoid. The associated circuitry can be omitted if no Hot Water Solenoid is used.
- Q3 controls the optional solar pump. The associated circuitry can be omitted if no solar pump is used.
- The LCD doesn't use a potentiometer for the contrast, a fixed resistor of 1k5 worked with all LCD's (different vendors, different colors) I have tested so far.

### Components

- You can use an Aduino UNO (or clone) or an Arduino Pro Mini (5V, 32Kb). Some other variants probably will work too but you might have to change the PIN definitons in the software.
- If you use an Arduino UNO, you can probably use its internal voltage regulator and ommit the 78L05. If you use an Arduino Pro Mini, you will definitely have to use the 78L05 like shown in the schematic. If you want to use 3.3V versions you will have to change some components (noticably the voltage dividers on the ADC's, and an LCD that can work at 3.3V) and change some calculations in the software.
- For use on 24V systems, you will need a 78L05 voltage regulator even for the Arduino UNO. You also have to change the input resistor (R4) of the ENGINE input to 22k.
- The relation between R1 and R2 is important. If you change any of these values, you *MUST* change their definitions in the software too! You don't need high precision resistors; the software will be able to calibrate around small deviations.
- Q1, Q2 and Q3 can be any NPN transistor or N-channel MOSFET, D1, D2 and D3 are generic diodes.
- The LCD is a generic 16x2 display (make sure it is a 5V version), you can use an I2C variant as well but then you have to free A5 (use one of the now vacant LCD ports) and adapt the software.
- You can, in addition to the onboard LED, connect an external LED (with appropriate series resistor) to pin 13.

### Commissioning

- Connect the temperature sensor(s). Perform a factory reset (will be done automatically if it is the first time the software runs) and the software will start pairing the sensor(s). If you use more than one sensor, you have to find out which one is for the boiler and which is for the solar panel. Some hot water will be handy with testing. ;-)

## Changes from 1.0 to 1.1
- The name was changed from BoilerOptimizer to HotWaterManager.
- The system can still be built around an Arduino but a dedicated circuit board [ThermalOptimizer](https://git.thefloatinglab.world/thefloatinglab/thermaloptimizer) is also available.
- Some IO ports in the Arduino version are changed to match the ports used in the dedicated "ThermalOptimizer" circuit board.
- The contrast pot of the LCD is changed into a fixed resistor.
- An additional output is now used to control an optional hot water solenoid.
- To allow the microcontroller to go into sleep mode, the display brightness is no longer controlled by PWM but with 3 binary outputs to facilitate 8 brightness levels.
- We no longer use a "reference voltage" but just use the power supply voltage.
- Diodes D1, D2, and D3 are now connected in the right way.
- The software has been significantly enhanced.
